Crate kcr_b3scale_infra_run

Crate kcr_b3scale_infra_run 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the b3scale.infra.run group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

b3scale.infra.run/v1

  • BBBFrontend

Modules

v1